"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const family_1 = require("../models/family");
const unit_1 = require("../models/unit");
const getSpouses_1 = require("../utils/getSpouses");
const setUnitDefShifts_1 = require("../utils/setUnitDefShifts");
exports.default = (store, parentIDs, type = 'root', isMain = false) => {
    const family = new family_1.default(store.getNextId(), type, isMain);
    const parents = family.main
        ? parentIDs.map(id => store.getNode(id)).sort((a, b) => (b.gender !== store.gender) ? -1 : 0)
        : parentIDs.map(id => store.getNode(id));
    family.pUnits.push(new unit_1.default(family.id, parents));
    let children = [];
    if (parents.length === 1) {
        children = parents[0].children
            .map(link => store.getNode(link.id));
    }
    else {
        const firstParent = parents[0];
        const secondParent = parents[1];
        children = firstParent.children
            .filter(fLink => secondParent.children.find(sLink => sLink.id === fLink.id))
            .map(link => store.getNode(link.id));
    }
    children.forEach(child => {
        if (child.spouses.length) {
            const spouses = getSpouses_1.default(store, [child]);
            if (spouses) {
                [...spouses.left.map(node => [node]), spouses.target, ...spouses.right.map(node => [node])]
                    .forEach(nodes => family.cUnits.push(new unit_1.default(family.id, nodes)));
            }
        }
        else {
            family.cUnits.push(new unit_1.default(family.id, [child]));
        }
    });
    setUnitDefShifts_1.default(family);
    return family;
};
