"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const byParents_1 = require("../children/byParents");
const getSpouses_1 = require("../utils/getSpouses");
const fixOverlaps_1 = require("./fixOverlaps");
const hasDiffParents_1 = require("../utils/hasDiffParents");
exports.default = (store) => {
    let families = [];
    if (hasDiffParents_1.default(store.rootNode)) {
        const bloodParentIDs = store.rootNode.parents
            .filter(rel => rel.type === 'blood')
            .map(rel => rel.id);
        const adoptedParentIDs = store.rootNode.parents
            .filter(rel => rel.type === 'adopted')
            .map(rel => rel.id);
        const bloodFamily = byParents_1.default(store, bloodParentIDs, 'root', true);
        const adoptedFamily = byParents_1.default(store, adoptedParentIDs);
        fixOverlaps_1.default(bloodFamily, adoptedFamily);
        families = [bloodFamily, adoptedFamily];
    }
    else {
        const parentIDs = store.rootNode.parents.map(rel => rel.id);
        const mainFamily = byParents_1.default(store, parentIDs, 'root', true);
        families.push(mainFamily);
        const parents = mainFamily.pUnits
            .map(unit => unit.nodes)
            .reduce((all, next) => all.concat(next), []);
        if (parents.length === 2) {
            const spouses = getSpouses_1.default(store, parents);
            if (spouses) {
                families = [
                    ...spouses.left.map(node => byParents_1.default(store, [node.id])),
                    ...families,
                    ...spouses.right.map(node => byParents_1.default(store, [node.id])),
                ];
            }
        }
    }
    if (families.length > 1) {
        for (let i = 1; i < families.length; i++) {
            families[i].left = families[i - 1].left + families[i - 1].width;
        }
    }
    families.forEach(family => store.families.set(family.id, family));
};
